diff --git a/include/conversation.php b/include/conversation.php
index a0d1177c3..7eda2277b 100644
--- a/include/conversation.php
+++ b/include/conversation.php
@@ -501,7 +501,7 @@ function conversation(App $a, array $items, $mode, $update, $preview = false, $o
$writable = false;
}
- if (in_array($mode, ['network-new', 'search', 'contact-posts'])) {
+ if (in_array($mode, ['filed', 'search', 'contact-posts'])) {
/*
* "New Item View" on network page or search page results
@@ -548,7 +548,7 @@ function conversation(App $a, array $items, $mode, $update, $preview = false, $o
$location_html = $locate['html'] ?: Strings::escapeHtml($locate['location'] ?: $locate['coord'] ?: '');
localize_item($item);
- if ($mode === 'network-new') {
+ if ($mode === 'filed') {
$dropping = true;
} else {
$dropping = false;
diff --git a/mod/network.php b/mod/network.php
deleted file mode 100644
index ef6b0b324..000000000
--- a/mod/network.php
+++ /dev/null
@@ -1,757 +0,0 @@
-.
- *
- */
-
-use Friendica\App;
-use Friendica\Content\ForumManager;
-use Friendica\Content\Nav;
-use Friendica\Content\Pager;
-use Friendica\Content\Widget;
-use Friendica\Content\Text\HTML;
-use Friendica\Core\ACL;
-use Friendica\Core\Hook;
-use Friendica\Core\Logger;
-use Friendica\Core\Renderer;
-use Friendica\Database\DBA;
-use Friendica\DI;
-use Friendica\Model\Contact;
-use Friendica\Model\Group;
-use Friendica\Model\Item;
-use Friendica\Model\Post\Category;
-use Friendica\Model\Profile;
-use Friendica\Model\User;
-use Friendica\Module\Contact as ModuleContact;
-use Friendica\Module\Security\Login;
-use Friendica\Util\DateTimeFormat;
-use Friendica\Util\Strings;
-
-function network_init(App $a)
-{
- if (!local_user()) {
- notice(DI::l10n()->t('Permission denied.'));
- return;
- }
-
- $is_a_date_query = false;
-
- $group_id = (($a->argc > 1 && is_numeric($a->argv[1])) ? intval($a->argv[1]) : 0);
-
- $cid = 0;
- if (!empty($_GET['contactid'])) {
- $cid = $_GET['contactid'];
- $_GET['nets'] = '';
- $group_id = 0;
- }
-
- if ($a->argc > 1) {
- for ($x = 1; $x < $a->argc; $x ++) {
- if (DI::dtFormat()->isYearMonthDay($a->argv[$x])) {
- $is_a_date_query = true;
- break;
- }
- }
- }
-
- // convert query string to array. remove friendica args
- $query_array = [];
- parse_str(parse_url(DI::args()->getQueryString(), PHP_URL_QUERY), $query_array);
-
- // fetch last used network view and redirect if needed
- if (!$is_a_date_query) {
- $sel_nets = $_GET['nets'] ?? '';
- $sel_tabs = network_query_get_sel_tab($a);
- $sel_groups = network_query_get_sel_group($a);
- $last_sel_tabs = DI::pConfig()->get(local_user(), 'network.view', 'tab.selected');
-
- $remember_tab = ($sel_tabs[0] === 'active' && is_array($last_sel_tabs) && $last_sel_tabs[0] !== 'active');
-
- $net_baseurl = '/network';
- $net_args = [];
-
- if ($sel_groups !== false) {
- $net_baseurl .= '/' . $sel_groups;
- }
-
- if ($remember_tab) {
- // redirect if current selected tab is '/network' and
- // last selected tab is _not_ '/network?order=activity'.
- // and this isn't a date query
-
- $tab_args = [
- 'order=activity', //all
- 'order=post', //postord
- 'conv=1', //conv
- 'star=1', //starred
- ];
-
- $k = array_search('active', $last_sel_tabs);
-
- if ($k != 3) {
- // parse out tab queries
- $dest_qa = [];
- $dest_qs = $tab_args[$k];
- parse_str($dest_qs, $dest_qa);
- $net_args = array_merge($net_args, $dest_qa);
- } else {
- $remember_tab = false;
- }
- }
-
- if ($sel_nets) {
- $net_args['nets'] = $sel_nets;
- }
-
- if ($remember_tab) {
- $net_args = array_merge($query_array, $net_args);
- $net_queries = http_build_query($net_args);
-
- $redir_url = ($net_queries ? $net_baseurl . '?' . $net_queries : $net_baseurl);
-
- DI::baseUrl()->redirect($redir_url);
- }
- }
-
- if (empty(DI::page()['aside'])) {
- DI::page()['aside'] = '';
- }
-
- if (!empty(User::getAccountTypeByString($a->argv[1] ?? ''))) {
- $accounttype = $a->argv[1];
- } else {
- $accounttype = '';
- }
-
- DI::page()['aside'] .= Widget::accounts('network', $accounttype);
- DI::page()['aside'] .= Group::sidebarWidget('network/0', 'network', 'standard', $group_id);
- DI::page()['aside'] .= ForumManager::widget(local_user(), $cid);
- DI::page()['aside'] .= Widget::postedByYear('network', local_user(), false);
- DI::page()['aside'] .= Widget::networks('network', $_GET['nets'] ?? '');
- DI::page()['aside'] .= Widget\SavedSearches::getHTML(DI::args()->getQueryString());
- DI::page()['aside'] .= Widget::fileAs('network', $_GET['file'] ?? '');
-}
-
-/**
- * Return selected tab from query
- *
- * urls -> returns
- * '/network' => $no_active = 'active'
- * '/network?order=activity' => $activity_active = 'active'
- * '/network?order=post' => $postord_active = 'active'
- * '/network?conv=1', => $conv_active = 'active'
- * '/network?star=1', => $starred_active = 'active'
- *
- * @param App $a
- * @return array ($no_active, $activity_active, $postord_active, $conv_active, $starred_active);
- */
-function network_query_get_sel_tab(App $a)
-{
- $no_active = '';
- $starred_active = '';
- $all_active = '';
- $conv_active = '';
- $postord_active = '';
-
- if (!empty($_GET['star'])) {
- $starred_active = 'active';
- }
-
- if (!empty($_GET['conv'])) {
- $conv_active = 'active';
- }
-
- if (($starred_active == '') && ($conv_active == '')) {
- $no_active = 'active';
- }
-
- if ($no_active == 'active' && !empty($_GET['order'])) {
- switch($_GET['order']) {
- case 'post' : $postord_active = 'active'; $no_active=''; break;
- case 'activity' : $all_active = 'active'; $no_active=''; break;
- }
- }
-
- return [$no_active, $all_active, $postord_active, $conv_active, $starred_active];
-}
-
-function network_query_get_sel_group(App $a)
-{
- $group = false;
-
- if ($a->argc >= 2 && is_numeric($a->argv[1])) {
- $group = $a->argv[1];
- }
-
- return $group;
-}
-
-/**
- * Sets the pager data and returns SQL
- *
- * @param App $a The global App
- * @param Pager $pager
- * @return string SQL with the appropriate LIMIT clause
- * @throws \Friendica\Network\HTTPException\InternalServerErrorException
- */
-function networkPager(App $a, Pager $pager)
-{
- if (DI::mode()->isMobile()) {
- $itemspage_network = DI::pConfig()->get(local_user(), 'system', 'itemspage_mobile_network',
- DI::config()->get('system', 'itemspage_network_mobile'));
- } else {
- $itemspage_network = DI::pConfig()->get(local_user(), 'system', 'itemspage_network',
- DI::config()->get('system', 'itemspage_network'));
- }
-
- // now that we have the user settings, see if the theme forces
- // a maximum item number which is lower then the user choice
- if (($a->force_max_items > 0) && ($a->force_max_items < $itemspage_network)) {
- $itemspage_network = $a->force_max_items;
- }
-
- $pager->setItemsPerPage($itemspage_network);
-}
-
-/**
- * Sets items as seen
- *
- * @param array $condition The array with the SQL condition
- * @throws \Friendica\Network\HTTPException\InternalServerErrorException
- */
-function networkSetSeen($condition)
-{
- if (empty($condition)) {
- return;
- }
-
- $unseen = Item::exists($condition);
-
- if ($unseen) {
- Item::update(['unseen' => false], $condition);
- }
-}
-
-/**
- * Create the conversation HTML
- *
- * @param App $a The global App
- * @param array $items Items of the conversation
- * @param Pager $pager
- * @param string $mode Display mode for the conversation
- * @param integer $update Used for the automatic reloading
- * @param string $ordering
- * @return string HTML of the conversation
- * @throws ImagickException
- * @throws \Friendica\Network\HTTPException\InternalServerErrorException
- */
-function networkConversation(App $a, $items, Pager $pager, $mode, $update, $ordering = '')
-{
- // Set this so that the conversation function can find out contact info for our wall-wall items
- $a->page_contact = $a->contact;
-
- if (!is_array($items)) {
- Logger::info('Expecting items to be an array.', ['items' => $items]);
- $items = [];
- }
-
- $o = conversation($a, $items, $mode, $update, false, $ordering, local_user());
-
- if (!$update) {
- if (DI::pConfig()->get(local_user(), 'system', 'infinite_scroll')) {
- $o .= HTML::scrollLoader();
- } else {
- $o .= $pager->renderMinimal(count($items));
- }
- }
-
- return $o;
-}
-
-function network_content(App $a, $update = 0, $parent = 0)
-{
- if (!local_user()) {
- return Login::form();
- }
-
- /// @TODO Is this really necessary? $a is already available to hooks
- $arr = ['query' => DI::args()->getQueryString()];
- Hook::callAll('network_content_init', $arr);
-
- if (DI::pConfig()->get(local_user(), 'system', 'infinite_scroll') && ($_GET['mode'] ?? '') != 'minimal') {
- $tpl = Renderer::getMarkupTemplate('infinite_scroll_head.tpl');
- $o = Renderer::replaceMacros($tpl, ['$reload_uri' => DI::args()->getQueryString()]);
- } else {
- $o = '';
- }
-
- $account = User::getAccountTypeByString($a->argv[1] ?? '');
-
- if (!empty($_GET['file'])) {
- $o .= networkFlatView($a, $update, $account);
- } else {
- $o .= networkThreadedView($a, $update, $parent, $account);
- }
-
- if (!$update && ($o === '')) {
- notice(DI::l10n()->t("No items found"));
- }
-
- return $o;
-}
-
-/**
- * Get the network content in flat view
- *
- * @param App $a The global App
- * @param integer $update Used for the automatic reloading
- * @return string HTML of the network content in flat view
- * @throws ImagickException
- * @throws \Friendica\Network\HTTPException\InternalServerErrorException
- * @global Pager $pager
- */
-function networkFlatView(App $a, $update, $account)
-{
- global $pager;
- // Rawmode is used for fetching new content at the end of the page
- $rawmode = (isset($_GET['mode']) && ($_GET['mode'] == 'raw'));
-
- $o = '';
-
- $file = $_GET['file'] ?? '';
-
- if (!$update && !$rawmode) {
- $tabs = network_tabs($a);
- $o .= $tabs;
-
- Nav::setSelected('network');
-
- $x = [
- 'is_owner' => true,
- 'allow_location' => $a->user['allow_location'],
- 'default_location' => $a->user['default-location'],
- 'nickname' => $a->user['nickname'],
- 'lockstate' => (is_array($a->user) &&
- (strlen($a->user['allow_cid']) || strlen($a->user['allow_gid']) ||
- strlen($a->user['deny_cid']) || strlen($a->user['deny_gid'])) ? 'lock' : 'unlock'),
- 'default_perms' => ACL::getDefaultUserPermissions($a->user),
- 'acl' => ACL::getFullSelectorHTML(DI::page(), $a->user, true),
- 'bang' => '',
- 'visitor' => 'block',
- 'profile_uid' => local_user(),
- 'content' => '',
- ];
-
- $o .= status_editor($a, $x);
-
- if (!DI::config()->get('theme', 'hide_eventlist')) {
- $o .= Profile::getBirthdays();
- $o .= Profile::getEventsReminderHTML();
- }
- }
-
- $pager = new Pager(DI::l10n(), DI::args()->getQueryString());
-
- networkPager($a, $pager);
-
- if (strlen($file)) {
- $item_params = ['order' => ['uri-id' => true]];
- $term_condition = ['name' => $file, 'type' => Category::FILE, 'uid' => local_user()];
- $term_params = ['order' => ['uri-id' => true], 'limit' => [$pager->getStart(), $pager->getItemsPerPage()]];
- $result = DBA::select('category-view', ['uri-id'], $term_condition, $term_params);
-
- $posts = [];
- while ($term = DBA::fetch($result)) {
- $posts[] = $term['uri-id'];
- }
- DBA::close($result);
-
- if (count($posts) == 0) {
- return '';
- }
- $item_condition = ['uid' => local_user(), 'uri-id' => $posts];
- } else {
- $item_params = ['order' => ['id' => true]];
- $item_condition = ['uid' => local_user()];
- $item_params['limit'] = [$pager->getStart(), $pager->getItemsPerPage()];
-
- networkSetSeen(['unseen' => true, 'uid' => local_user()]);
- }
-
- if (!empty($account)) {
- $item_condition['contact-type'] = $account;
- }
-
- $result = Item::selectForUser(local_user(), [], $item_condition, $item_params);
- $items = Item::inArray($result);
- $o .= networkConversation($a, $items, $pager, 'network-new', $update);
-
- return $o;
-}
-
-/**
- * Get the network content in threaded view
- *
- * @param App $a The global App
- * @param integer $update Used for the automatic reloading
- * @param integer $parent
- * @return string HTML of the network content in flat view
- * @throws ImagickException
- * @throws \Friendica\Network\HTTPException\InternalServerErrorException
- * @global Pager $pager
- */
-function networkThreadedView(App $a, $update, $parent, $account)
-{
- /// @TODO this will have to be converted to a static property of the converted Module\Network class
- global $pager;
-
- // Rawmode is used for fetching new content at the end of the page
- $rawmode = (isset($_GET['mode']) AND ($_GET['mode'] == 'raw'));
-
- $last_received = isset($_GET['last_received']) ? DateTimeFormat::utc($_GET['last_received']) : '';
- $last_commented = isset($_GET['last_commented']) ? DateTimeFormat::utc($_GET['last_commented']) : '';
- $last_created = isset($_GET['last_created']) ? DateTimeFormat::utc($_GET['last_created']) : '';
- $last_uriid = isset($_GET['last_uriid']) ? intval($_GET['last_uriid']) : 0;
-
- $datequery = $datequery2 = '';
-
- $gid = 0;
-
- $default_permissions = [];
-
- if ($a->argc > 1) {
- for ($x = 1; $x < $a->argc; $x ++) {
- if (DI::dtFormat()->isYearMonthDay($a->argv[$x])) {
- if ($datequery) {
- $datequery2 = Strings::escapeHtml($a->argv[$x]);
- } else {
- $datequery = Strings::escapeHtml($a->argv[$x]);
- $_GET['order'] = 'post';
- }
- } elseif (intval($a->argv[$x])) {
- $gid = intval($a->argv[$x]);
- $default_permissions['allow_gid'] = [$gid];
- }
- }
- }
-
- $o = '';
-
- $cid = intval($_GET['contactid'] ?? 0);
- $star = intval($_GET['star'] ?? 0);
- $conv = intval($_GET['conv'] ?? 0);
- $order = Strings::escapeTags(($_GET['order'] ?? '') ?: 'activity');
- $nets = $_GET['nets'] ?? '';
-
- $allowedCids = [];
- if ($cid) {
- $allowedCids[] = (int) $cid;
- } elseif ($nets) {
- $condition = [
- 'uid' => local_user(),
- 'network' => $nets,
- 'self' => false,
- 'blocked' => false,
- 'pending' => false,
- 'archive' => false,
- 'rel' => [Contact::SHARING, Contact::FRIEND],
- ];
- $contactStmt = DBA::select('contact', ['id'], $condition);
- while ($contact = DBA::fetch($contactStmt)) {
- $allowedCids[] = (int) $contact['id'];
- }
- DBA::close($contactStmt);
- }
-
- if (count($allowedCids)) {
- $default_permissions['allow_cid'] = $allowedCids;
- }
-
- if (!$update && !$rawmode) {
- $tabs = network_tabs($a);
- $o .= $tabs;
-
- Nav::setSelected('network');
-
- $content = '';
-
- if ($cid) {
- // If $cid belongs to a communitity forum or a privat goup,.add a mention to the status editor
- $condition = ["`id` = ? AND (`forum` OR `prv`)", $cid];
- $contact = DBA::selectFirst('contact', ['addr'], $condition);
- if (!empty($contact['addr'])) {
- $content = '!' . $contact['addr'];
- }
- }
-
- $x = [
- 'is_owner' => true,
- 'allow_location' => $a->user['allow_location'],
- 'default_location' => $a->user['default-location'],
- 'nickname' => $a->user['nickname'],
- 'lockstate' => ($gid || $cid || $nets || (is_array($a->user) &&
- (strlen($a->user['allow_cid']) || strlen($a->user['allow_gid']) ||
- strlen($a->user['deny_cid']) || strlen($a->user['deny_gid']))) ? 'lock' : 'unlock'),
- 'default_perms' => ACL::getDefaultUserPermissions($a->user),
- 'acl' => ACL::getFullSelectorHTML(DI::page(), $a->user, true, $default_permissions),
- 'bang' => (($gid || $cid || $nets) ? '!' : ''),
- 'visitor' => 'block',
- 'profile_uid' => local_user(),
- 'content' => $content,
- ];
-
- $o .= status_editor($a, $x);
- }
-
- $conditionFields = ['uid' => local_user()];
- $conditionStrings = [];
-
- if (!empty($account)) {
- $conditionFields['contact-type'] = $account;
- }
-
- if ($star) {
- $conditionFields['starred'] = true;
- }
- if ($conv) {
- $conditionFields['mention'] = true;
- }
- if ($nets) {
- $conditionFields['network'] = $nets;
- }
-
- if ($datequery) {
- $conditionStrings = DBA::mergeConditions($conditionStrings, ["`received` <= ? ", DateTimeFormat::convert($datequery, 'UTC', date_default_timezone_get())]);
- }
- if ($datequery2) {
- $conditionStrings = DBA::mergeConditions($conditionStrings, ["`received` >= ? ", DateTimeFormat::convert($datequery2, 'UTC', date_default_timezone_get())]);
- }
-
- if ($gid) {
- $group = DBA::selectFirst('group', ['name'], ['id' => $gid, 'uid' => local_user()]);
- if (!DBA::isResult($group)) {
- if ($update) {
- exit();
- }
- notice(DI::l10n()->t('No such group'));
- DI::baseUrl()->redirect('network/0');
- // NOTREACHED
- }
-
- $conditionStrings = DBA::mergeConditions($conditionStrings, ["`contact-id` IN (SELECT `contact-id` FROM `group_member` WHERE `gid` = ?)", $gid]);
-
- $o = Renderer::replaceMacros(Renderer::getMarkupTemplate('section_title.tpl'), [
- '$title' => DI::l10n()->t('Group: %s', $group['name'])
- ]) . $o;
- } elseif ($cid) {
- $contact = Contact::getById($cid);
- if (DBA::isResult($contact)) {
- $conditionFields['contact-id'] = $cid;
-
- $o = Renderer::replaceMacros(Renderer::getMarkupTemplate('viewcontact_template.tpl'), [
- 'contacts' => [ModuleContact::getContactTemplateVars($contact)],
- 'id' => 'network',
- ]) . $o;
- } else {
- notice(DI::l10n()->t('Invalid contact.'));
- DI::baseUrl()->redirect('network');
- // NOTREACHED
- }
- } elseif (!$update && !DI::config()->get('theme', 'hide_eventlist')) {
- $o .= Profile::getBirthdays();
- $o .= Profile::getEventsReminderHTML();
- }
-
- // Normal conversation view
- if ($order === 'post') {
- $ordering = '`received`';
- $order_mode = 'received';
- } else {
- $ordering = '`commented`';
- $order_mode = 'commented';
- }
-
- $pager = new Pager(DI::l10n(), DI::args()->getQueryString());
-
- networkPager($a, $pager);
-
- if (DI::pConfig()->get(local_user(), 'system', 'infinite_scroll')) {
- $pager->setPage(1);
- }
-
- // Currently only the order modes "received" and "commented" are in use
- switch ($order_mode) {
- case 'received':
- if ($last_received != '') {
- $conditionStrings = DBA::mergeConditions($conditionStrings, ["`received` < ?", $last_received]);
- }
- break;
- case 'commented':
- if ($last_commented != '') {
- $conditionStrings = DBA::mergeConditions($conditionStrings, ["`commented` < ?", $last_commented]);
- }
- break;
- case 'created':
- if ($last_created != '') {
- $conditionStrings = DBA::mergeConditions($conditionStrings, ["`created` < ?", $last_created]);
- }
- break;
- case 'uriid':
- if ($last_uriid > 0) {
- $conditionStrings = DBA::mergeConditions($conditionStrings, ["`uri-id` < ?", $last_uriid]);
- }
- break;
- }
-
- // Fetch a page full of parent items for this page
- if ($update) {
- if (!empty($parent)) {
- // Load only a single thread
- $conditionFields['parent'] = $parent;
- } elseif ($order === 'post') {
- // Only load new toplevel posts
- $conditionFields['unseen'] = true;
- $conditionFields['gravity'] = GRAVITY_PARENT;
- } else {
- // Load all unseen items
- $conditionFields['unseen'] = true;
- }
-
- $params = ['order' => [$order_mode => true], 'limit' => 100];
- $table = 'network-item-view';
- } else {
- $params = ['order' => [$order_mode => true], 'limit' => [$pager->getStart(), $pager->getItemsPerPage()]];
- $table = 'network-thread-view';
- }
- $r = DBA::selectToArray($table, [], DBA::mergeConditions($conditionFields, $conditionStrings), $params);
-
- return $o . network_display_post($a, $pager, (!$gid && !$cid && !$star), $update, $ordering, $r);
-}
-
-function network_display_post($a, $pager, $mark_all, $update, $ordering, $items)
-{
- $parents_str = '';
-
- if (DBA::isResult($items)) {
- $parents_arr = [];
-
- foreach ($items as $item) {
- if (!in_array($item['parent'], $parents_arr) && ($item['parent'] > 0)) {
- $parents_arr[] = $item['parent'];
- }
- }
- $parents_str = implode(', ', $parents_arr);
- }
-
- $pager->setQueryString(DI::args()->getQueryString());
-
- // We aren't going to try and figure out at the item, group, and page
- // level which items you've seen and which you haven't. If you're looking
- // at the top level network page just mark everything seen.
-
- if ($mark_all) {
- $condition = ['unseen' => true, 'uid' => local_user()];
- networkSetSeen($condition);
- } elseif ($parents_str) {
- $condition = ["`uid` = ? AND `unseen` AND `parent` IN (" . DBA::escape($parents_str) . ")", local_user()];
- networkSetSeen($condition);
- }
-
- return networkConversation($a, $items, $pager, 'network', $update, $ordering);
-}
-
-/**
- * Get the network tabs menu
- *
- * @param App $a The global App
- * @return string Html of the networktab
- * @throws \Friendica\Network\HTTPException\InternalServerErrorException
- */
-function network_tabs(App $a)
-{
- // item filter tabs
- /// @TODO fix this logic, reduce duplication
- /// DI::page()['content'] .= '
';
- list($no_active, $all_active, $post_active, $conv_active, $starred_active) = network_query_get_sel_tab($a);
-
- // if no tabs are selected, defaults to activitys
- if ($no_active == 'active') {
- $all_active = 'active';
- }
-
- $cmd = DI::args()->getCommand();
-
- $def_param = [];
- if (!empty($_GET['contactid'])) {
- $def_param['contactid'] = $_GET['contactid'];
- }
-
- // tabs
- $tabs = [
- [
- 'label' => DI::l10n()->t('Latest Activity'),
- 'url' => $cmd . '?' . http_build_query(array_merge($def_param, ['order' => 'activity'])),
- 'sel' => $all_active,
- 'title' => DI::l10n()->t('Sort by latest activity'),
- 'id' => 'activity-order-tab',
- 'accesskey' => 'e',
- ],
- [
- 'label' => DI::l10n()->t('Latest Posts'),
- 'url' => $cmd . '?' . http_build_query(array_merge($def_param, ['order' => 'post'])),
- 'sel' => $post_active,
- 'title' => DI::l10n()->t('Sort by post received date'),
- 'id' => 'post-order-tab',
- 'accesskey' => 't',
- ],
- ];
-
- $tabs[] = [
- 'label' => DI::l10n()->t('Personal'),
- 'url' => $cmd . '?' . http_build_query(array_merge($def_param, ['conv' => true])),
- 'sel' => $conv_active,
- 'title' => DI::l10n()->t('Posts that mention or involve you'),
- 'id' => 'personal-tab',
- 'accesskey' => 'r',
- ];
-
- $tabs[] = [
- 'label' => DI::l10n()->t('Starred'),
- 'url' => $cmd . '?' . http_build_query(array_merge($def_param, ['star' => true])),
- 'sel' => $starred_active,
- 'title' => DI::l10n()->t('Favourite Posts'),
- 'id' => 'starred-posts-tab',
- 'accesskey' => 'm',
- ];
-
- // save selected tab, but only if not in file mode
- if (empty($_GET['file'])) {
- DI::pConfig()->set(local_user(), 'network.view', 'tab.selected', [
- $all_active, $post_active, $conv_active, $starred_active
- ]);
- }
-
- $arr = ['tabs' => $tabs];
- Hook::callAll('network_tabs', $arr);
-
- $tpl = Renderer::getMarkupTemplate('common_tabs.tpl');
-
- return Renderer::replaceMacros($tpl, ['$tabs' => $arr['tabs']]);
-
- // --- end item filter tabs
-}
diff --git a/mod/update_network.php b/mod/update_network.php
deleted file mode 100644
index 4610a3093..000000000
--- a/mod/update_network.php
+++ /dev/null
@@ -1,50 +0,0 @@
-.
- *
- * See update_profile.php for documentation
- */
-
-use Friendica\App;
-use Friendica\Core\System;
-use Friendica\DI;
-use Friendica\Model\Item;
-
-require_once "mod/network.php";
-
-function update_network_content(App $a)
-{
- if (!isset($_GET['p']) || !isset($_GET['item'])) {
- exit();
- }
-
- $profile_uid = intval($_GET['p']);
-
- if (!DI::pConfig()->get($profile_uid, "system", "no_auto_update") || ($_GET["force"] == 1)) {
- if (!empty($_GET['item'])) {
- $item = Item::selectFirst(['parent'], ['id' => $_GET['item']]);
- $parentid = $item['parent'] ?? 0;
- } else {
- $parentid = 0;
- }
- $text = network_content($a, $profile_uid, $parentid);
- } else {
- $text = "";
- }
- System::htmlUpdateExit($text);
-}
diff --git a/src/App.php b/src/App.php
index adb4e55ae..c69abf212 100644
--- a/src/App.php
+++ b/src/App.php
@@ -77,7 +77,6 @@ class App
public $sourcename = '';
public $videowidth = 425;
public $videoheight = 350;
- public $force_max_items = 0;
public $theme_events_in_profile = true;
public $queue;
diff --git a/src/Content/Widget.php b/src/Content/Widget.php
index 90373e8c3..e18f70631 100644
--- a/src/Content/Widget.php
+++ b/src/Content/Widget.php
@@ -542,26 +542,4 @@ class Widget
return self::filter('accounttype', DI::l10n()->t('Account Types'), '',
DI::l10n()->t('All'), $base, $accounts, $accounttype);
}
-
- /**
- * Display the accounts sidebar
- * The account type is added to the path
- *
- * @param string $base Basepath
- * @param string $accounttype Acount type (person, organisation, news, community)
- * @return string
- */
- public static function accounts(string $base, string $accounttype)
- {
- return Renderer::replaceMacros(Renderer::getMarkupTemplate('widget/accounts.tpl'), [
- '$title' => DI::l10n()->t('Account Types'),
- '$content' => $base,
- '$accounttype' => ($accounttype ?? ''),
- '$all' => DI::l10n()->t('All'),
- '$person' => DI::l10n()->t('Persons'),
- '$organisation' => DI::l10n()->t('Organisations'),
- '$news' => DI::l10n()->t('News'),
- '$community' => DI::l10n()->t('Forums'),
- ]);
- }
}
diff --git a/src/Core/Renderer.php b/src/Core/Renderer.php
index 24f003417..1ccad740b 100644
--- a/src/Core/Renderer.php
+++ b/src/Core/Renderer.php
@@ -51,7 +51,6 @@ class Renderer
'sourcename' => '',
'videowidth' => 425,
'videoheight' => 350,
- 'force_max_items' => 0,
'stylesheet' => '',
'template_engine' => 'smarty3',
];
diff --git a/src/Module/Conversation/Community.php b/src/Module/Conversation/Community.php
index 5ce76bd17..a960bf5e0 100644
--- a/src/Module/Conversation/Community.php
+++ b/src/Module/Conversation/Community.php
@@ -42,7 +42,8 @@ class Community extends BaseModule
{
protected static $page_style;
protected static $content;
- protected static $accounttype;
+ protected static $accountTypeString;
+ protected static $accountType;
protected static $itemsPerPage;
protected static $min_id;
protected static $max_id;
@@ -89,7 +90,7 @@ class Community extends BaseModule
Nav::setSelected('community');
- DI::page()['aside'] .= Widget::accounts('community/' . self::$content, $parameters['accounttype'] ?? '');
+ DI::page()['aside'] .= Widget::accounttypes('community/' . self::$content, self::$accountTypeString);
if (local_user() && DI::config()->get('system', 'community_no_sharer')) {
$path = self::$content;
@@ -192,7 +193,8 @@ class Community extends BaseModule
throw new HTTPException\ForbiddenException(DI::l10n()->t('Access denied.'));
}
- self::$accounttype = User::getAccountTypeByString($parameters['accounttype'] ?? '');
+ self::$accountTypeString = $_GET['accounttype'] ?? $parameters['accounttype'] ?? '';
+ self::$accountType = User::getAccountTypeByString(self::$accountTypeString);
self::$content = $parameters['content'] ?? '';
if (!self::$content) {
@@ -234,12 +236,6 @@ class Community extends BaseModule
DI::config()->get('system', 'itemspage_network'));
}
- // now that we have the user settings, see if the theme forces
- // a maximum item number which is lower then the user choice
- if ((DI::app()->force_max_items > 0) && (DI::app()->force_max_items < self::$itemsPerPage)) {
- self::$itemsPerPage = DI::app()->force_max_items;
- }
-
if (!empty($_GET['item'])) {
$item = Item::selectFirst(['parent'], ['id' => $_GET['item']]);
self::$item_id = $item['parent'] ?? 0;
@@ -317,14 +313,14 @@ class Community extends BaseModule
private static function selectItems($min_id, $max_id, $item_id, $itemspage)
{
if (self::$content == 'local') {
- if (!is_null(self::$accounttype)) {
- $condition = ["`wall` AND `origin` AND `private` = ? AND `owner`.`contact-type` = ?", Item::PUBLIC, self::$accounttype];
+ if (!is_null(self::$accountType)) {
+ $condition = ["`wall` AND `origin` AND `private` = ? AND `owner`.`contact-type` = ?", Item::PUBLIC, self::$accountType];
} else {
$condition = ["`wall` AND `origin` AND `private` = ?", Item::PUBLIC];
}
} elseif (self::$content == 'global') {
- if (!is_null(self::$accounttype)) {
- $condition = ["`uid` = ? AND `private` = ? AND `owner`.`contact-type` = ?", 0, Item::PUBLIC, self::$accounttype];
+ if (!is_null(self::$accountType)) {
+ $condition = ["`uid` = ? AND `private` = ? AND `owner`.`contact-type` = ?", 0, Item::PUBLIC, self::$accountType];
} else {
$condition = ["`uid` = ? AND `private` = ?", 0, Item::PUBLIC];
}
diff --git a/src/Module/Conversation/Network.php b/src/Module/Conversation/Network.php
new file mode 100644
index 000000000..f21b3816a
--- /dev/null
+++ b/src/Module/Conversation/Network.php
@@ -0,0 +1,448 @@
+getQueryString());
+ DI::page()['aside'] .= Widget::fileAs('filed', null);
+
+ $arr = ['query' => DI::args()->getQueryString()];
+ Hook::callAll('network_content_init', $arr);
+
+ $o = '';
+
+ // Fetch a page full of parent items for this page
+ $params = ['limit' => self::$itemsPerPage];
+ $table = 'network-thread-view';
+
+ $items = self::getItems($table, $params);
+
+ if (DI::pConfig()->get(local_user(), 'system', 'infinite_scroll') && ($_GET['mode'] ?? '') != 'minimal') {
+ $tpl = Renderer::getMarkupTemplate('infinite_scroll_head.tpl');
+ $o .= Renderer::replaceMacros($tpl, ['$reload_uri' => DI::args()->getQueryString()]);
+ }
+
+ if (!(isset($_GET['mode']) AND ($_GET['mode'] == 'raw'))) {
+ $o .= self::getTabsHTML(self::$selectedTab);
+
+ Nav::setSelected(DI::args()->get(0));
+
+ $content = '';
+
+ if (self::$forumContactId) {
+ // If self::$forumContactId belongs to a communitity forum or a privat goup,.add a mention to the status editor
+ $condition = ["`id` = ? AND (`forum` OR `prv`)", self::$forumContactId];
+ $contact = DBA::selectFirst('contact', ['addr'], $condition);
+ if (!empty($contact['addr'])) {
+ $content = '!' . $contact['addr'];
+ }
+ }
+
+ $a = DI::app();
+
+ $default_permissions = [];
+ if (self::$groupId) {
+ $default_permissions['allow_gid'] = [self::$groupId];
+ }
+
+ $allowedCids = [];
+ if (self::$forumContactId) {
+ $allowedCids[] = (int) self::$forumContactId;
+ } elseif (self::$network) {
+ $condition = [
+ 'uid' => local_user(),
+ 'network' => self::$network,
+ 'self' => false,
+ 'blocked' => false,
+ 'pending' => false,
+ 'archive' => false,
+ 'rel' => [Contact::SHARING, Contact::FRIEND],
+ ];
+ $contactStmt = DBA::select('contact', ['id'], $condition);
+ while ($contact = DBA::fetch($contactStmt)) {
+ $allowedCids[] = (int) $contact['id'];
+ }
+ DBA::close($contactStmt);
+ }
+
+ if (count($allowedCids)) {
+ $default_permissions['allow_cid'] = $allowedCids;
+ }
+
+ $x = [
+ 'is_owner' => true,
+ 'allow_location' => $a->user['allow_location'],
+ 'default_location' => $a->user['default-location'],
+ 'nickname' => $a->user['nickname'],
+ 'lockstate' => (self::$groupId || self::$forumContactId || self::$network || (is_array($a->user) &&
+ (strlen($a->user['allow_cid']) || strlen($a->user['allow_gid']) ||
+ strlen($a->user['deny_cid']) || strlen($a->user['deny_gid']))) ? 'lock' : 'unlock'),
+ 'default_perms' => ACL::getDefaultUserPermissions($a->user),
+ 'acl' => ACL::getFullSelectorHTML(DI::page(), $a->user, true, $default_permissions),
+ 'bang' => ((self::$groupId || self::$forumContactId || self::$network) ? '!' : ''),
+ 'visitor' => 'block',
+ 'profile_uid' => local_user(),
+ 'content' => $content,
+ ];
+
+ $o .= status_editor($a, $x);
+ }
+
+ if (self::$groupId) {
+ $group = DBA::selectFirst('group', ['name'], ['id' => self::$groupId, 'uid' => local_user()]);
+ if (!DBA::isResult($group)) {
+ notice(DI::l10n()->t('No such group'));
+ }
+
+ $o = Renderer::replaceMacros(Renderer::getMarkupTemplate('section_title.tpl'), [
+ '$title' => DI::l10n()->t('Group: %s', $group['name'])
+ ]) . $o;
+ } elseif (self::$forumContactId) {
+ $contact = Contact::getById(self::$forumContactId);
+ if (DBA::isResult($contact)) {
+ $o = Renderer::replaceMacros(Renderer::getMarkupTemplate('viewcontact_template.tpl'), [
+ 'contacts' => [ModuleContact::getContactTemplateVars($contact)],
+ 'id' => DI::args()->get(0),
+ ]) . $o;
+ } else {
+ notice(DI::l10n()->t('Invalid contact.'));
+ }
+ } elseif (!DI::config()->get('theme', 'hide_eventlist')) {
+ $o .= Profile::getBirthdays();
+ $o .= Profile::getEventsReminderHTML();
+ }
+
+ if (self::$order === 'received') {
+ $ordering = '`received`';
+ } else {
+ $ordering = '`commented`';
+ }
+
+ $o .= conversation(DI::app(), $items, 'network', false, false, $ordering, local_user());
+
+ if (DI::pConfig()->get(local_user(), 'system', 'infinite_scroll')) {
+ $o .= HTML::scrollLoader();
+ } else {
+ $pager = new BoundariesPager(
+ DI::l10n(),
+ DI::args()->getQueryString(),
+ $items[0][self::$order],
+ $items[count($items) - 1][self::$order],
+ self::$itemsPerPage
+ );
+
+ $o .= $pager->renderMinimal(count($items));
+ }
+
+ return $o;
+ }
+
+ /**
+ * Sets items as seen
+ *
+ * @param array $condition The array with the SQL condition
+ * @throws \Friendica\Network\HTTPException\InternalServerErrorException
+ */
+ private static function setItemsSeenByCondition(array $condition)
+ {
+ if (empty($condition)) {
+ return;
+ }
+
+ $unseen = Item::exists($condition);
+
+ if ($unseen) {
+ Item::update(['unseen' => false], $condition);
+ }
+ }
+
+ /**
+ * Get the network tabs menu
+ *
+ * @param string $selectedTab
+ * @return string Html of the network tabs
+ * @throws \Friendica\Network\HTTPException\InternalServerErrorException
+ */
+ private static function getTabsHTML(string $selectedTab)
+ {
+ $cmd = DI::args()->getCommand();
+
+ // tabs
+ $tabs = [
+ [
+ 'label' => DI::l10n()->t('Latest Activity'),
+ 'url' => $cmd . '?' . http_build_query(['order' => 'commented']),
+ 'sel' => !$selectedTab || $selectedTab == 'commented' ? 'active' : '',
+ 'title' => DI::l10n()->t('Sort by latest activity'),
+ 'id' => 'activity-order-tab',
+ 'accesskey' => 'e',
+ ],
+ [
+ 'label' => DI::l10n()->t('Latest Posts'),
+ 'url' => $cmd . '?' . http_build_query(['order' => 'received']),
+ 'sel' => $selectedTab == 'received' ? 'active' : '',
+ 'title' => DI::l10n()->t('Sort by post received date'),
+ 'id' => 'post-order-tab',
+ 'accesskey' => 't',
+ ],
+ [
+ 'label' => DI::l10n()->t('Personal'),
+ 'url' => $cmd . '?' . http_build_query(['mention' => true]),
+ 'sel' => $selectedTab == 'mention' ? 'active' : '',
+ 'title' => DI::l10n()->t('Posts that mention or involve you'),
+ 'id' => 'personal-tab',
+ 'accesskey' => 'r',
+ ],
+ [
+ 'label' => DI::l10n()->t('Starred'),
+ 'url' => $cmd . '?' . http_build_query(['star' => true]),
+ 'sel' => $selectedTab == 'star' ? 'active' : '',
+ 'title' => DI::l10n()->t('Favourite Posts'),
+ 'id' => 'starred-posts-tab',
+ 'accesskey' => 'm',
+ ],
+ ];
+
+ $arr = ['tabs' => $tabs];
+ Hook::callAll('network_tabs', $arr);
+
+ $tpl = Renderer::getMarkupTemplate('common_tabs.tpl');
+
+ return Renderer::replaceMacros($tpl, ['$tabs' => $arr['tabs']]);
+ }
+
+ protected static function parseRequest(array $parameters, array $get)
+ {
+ self::$groupId = $parameters['group_id'] ?? 0;
+
+ self::$forumContactId = $parameters['contact_id'] ?? 0;
+
+ self::$selectedTab = DI::pConfig()->get(local_user(), 'network.view', 'selected_tab', '');
+
+ if (!empty($get['star'])) {
+ self::$selectedTab = 'star';
+ }
+
+ if (!empty($get['mention'])) {
+ self::$selectedTab = 'mention';
+ }
+
+ if (!empty($get['order'])) {
+ self::$selectedTab = $get['order'];
+ }
+
+ DI::pConfig()->set(local_user(), 'network.view', 'selected_tab', self::$selectedTab);
+
+ self::$star = intval($get['star'] ?? 0);
+ self::$mention = intval($_GET['mention'] ?? 0);
+ self::$order = in_array(self::$selectedTab, ['received', 'commented', 'created', 'uriid']) ? self::$selectedTab : 'commented';
+
+ self::$accountTypeString = $_GET['accounttype'] ?? $parameters['accounttype'] ?? '';
+ self::$accountType = User::getAccountTypeByString(self::$accountTypeString);
+
+ self::$network = $get['nets'] ?? '';
+
+ self::$dateFrom = $parameters['from'] ?? '';
+ self::$dateTo = $parameters['to'] ?? '';
+
+ if (DI::mode()->isMobile()) {
+ self::$itemsPerPage = DI::pConfig()->get(local_user(), 'system', 'itemspage_mobile_network',
+ DI::config()->get('system', 'itemspage_network_mobile'));
+ } else {
+ self::$itemsPerPage = DI::pConfig()->get(local_user(), 'system', 'itemspage_network',
+ DI::config()->get('system', 'itemspage_network'));
+ }
+
+ self::$min_id = $_GET['min_id'] ?? null;
+ self::$max_id = $_GET['max_id'] ?? null;
+
+ switch (self::$selectedTab) {
+ case 'received':
+ self::$max_id = $_GET['last_received'] ?? self::$max_id;
+ break;
+ case 'commented':
+ self::$max_id = $_GET['last_commented'] ?? self::$max_id;
+ break;
+ case 'created':
+ self::$max_id = $_GET['last_created'] ?? self::$max_id;
+ break;
+ case 'uriid':
+ self::$max_id = $_GET['last_uriid'] ?? self::$max_id;
+ break;
+ }
+ }
+
+ protected static function getItems(string $table, array $params, array $conditionFields = [])
+ {
+ $conditionFields['uid'] = local_user();
+ $conditionStrings = [];
+
+ if (!is_null(self::$accountType)) {
+ $conditionFields['contact-type'] = self::$accountType;
+ }
+
+ if (self::$star) {
+ $conditionFields['starred'] = true;
+ }
+ if (self::$mention) {
+ $conditionFields['mention'] = true;
+ }
+ if (self::$network) {
+ $conditionFields['network'] = self::$network;
+ }
+
+ if (self::$dateFrom) {
+ $conditionStrings = DBA::mergeConditions($conditionStrings, ["`received` <= ? ", DateTimeFormat::convert(self::$dateFrom, 'UTC', date_default_timezone_get())]);
+ }
+ if (self::$dateTo) {
+ $conditionStrings = DBA::mergeConditions($conditionStrings, ["`received` >= ? ", DateTimeFormat::convert(self::$dateTo, 'UTC', date_default_timezone_get())]);
+ }
+
+ if (self::$groupId) {
+ $conditionStrings = DBA::mergeConditions($conditionStrings, ["`contact-id` IN (SELECT `contact-id` FROM `group_member` WHERE `gid` = ?)", self::$groupId]);
+ } elseif (self::$forumContactId) {
+ $conditionFields['contact-id'] = self::$forumContactId;
+ }
+
+ // Currently only the order modes "received" and "commented" are in use
+ if (isset(self::$max_id)) {
+ switch (self::$order) {
+ case 'received':
+ $conditionStrings = DBA::mergeConditions($conditionStrings, ["`received` < ?", self::$max_id]);
+ break;
+ case 'commented':
+ $conditionStrings = DBA::mergeConditions($conditionStrings, ["`commented` < ?", self::$max_id]);
+ break;
+ case 'created':
+ $conditionStrings = DBA::mergeConditions($conditionStrings, ["`created` < ?", self::$max_id]);
+ break;
+ case 'uriid':
+ $conditionStrings = DBA::mergeConditions($conditionStrings, ["`uri-id` < ?", self::$max_id]);
+ break;
+ }
+ }
+
+ if (isset(self::$min_id)) {
+ switch (self::$order) {
+ case 'received':
+ $conditionStrings = DBA::mergeConditions($conditionStrings, ["`received` > ?", self::$min_id]);
+ break;
+ case 'commented':
+ $conditionStrings = DBA::mergeConditions($conditionStrings, ["`commented` > ?", self::$min_id]);
+ break;
+ case 'created':
+ $conditionStrings = DBA::mergeConditions($conditionStrings, ["`created` > ?", self::$min_id]);
+ break;
+ case 'uriid':
+ $conditionStrings = DBA::mergeConditions($conditionStrings, ["`uri-id` > ?", self::$min_id]);
+ break;
+ }
+ }
+
+ if (isset(self::$min_id) && !isset(self::$max_id)) {
+ // min_id quirk: querying in reverse order with min_id gets the most recent rows, regardless of how close
+ // they are to min_id. We change the query ordering to get the expected data, and we need to reverse the
+ // order of the results.
+ $params['order'] = [self::$order => false];
+ } else {
+ $params['order'] = [self::$order => true];
+ }
+
+ $items = DBA::selectToArray($table, [], DBA::mergeConditions($conditionFields, $conditionStrings), $params);
+
+ // min_id quirk, continued
+ if (isset(self::$min_id) && !isset(self::$max_id)) {
+ $items = array_reverse($items);
+ }
+
+ $parents_str = '';
+ if (DBA::isResult($items)) {
+ $parents_arr = [];
+
+ foreach ($items as $item) {
+ if (!in_array($item['parent'], $parents_arr) && ($item['parent'] > 0)) {
+ $parents_arr[] = $item['parent'];
+ }
+ }
+ $parents_str = implode(', ', $parents_arr);
+ }
+
+ // We aren't going to try and figure out at the item, group, and page
+ // level which items you've seen and which you haven't. If you're looking
+ // at the top level network page just mark everything seen.
+ if (!self::$groupId && !self::$forumContactId && self::$selectedTab != 'star') {
+ $condition = ['unseen' => true, 'uid' => local_user()];
+ self::setItemsSeenByCondition($condition);
+ } elseif ($parents_str) {
+ $condition = ["`uid` = ? AND `unseen` AND `parent` IN (" . DBA::escape($parents_str) . ")", local_user()];
+ self::setItemsSeenByCondition($condition);
+ }
+
+ return $items;
+ }
+}
diff --git a/src/Module/Profile/Status.php b/src/Module/Profile/Status.php
index fbc287e6a..ccb1d9eef 100644
--- a/src/Module/Profile/Status.php
+++ b/src/Module/Profile/Status.php
@@ -180,12 +180,6 @@ class Status extends BaseProfile
DI::config()->get('system', 'itemspage_network'));
}
- // now that we have the user settings, see if the theme forces
- // a maximum item number which is lower then the user choice
- if (($a->force_max_items > 0) && ($a->force_max_items < $itemspage_network)) {
- $itemspage_network = $a->force_max_items;
- }
-
$pager = new Pager(DI::l10n(), $args->getQueryString(), $itemspage_network);
$pager_sql = sprintf(" LIMIT %d, %d ", $pager->getStart(), $pager->getItemsPerPage());
diff --git a/src/Module/Search/Filed.php b/src/Module/Search/Filed.php
new file mode 100644
index 000000000..505950f71
--- /dev/null
+++ b/src/Module/Search/Filed.php
@@ -0,0 +1,85 @@
+getCommand(), $_GET['file'] ?? '');
+
+ if (DI::pConfig()->get(local_user(), 'system', 'infinite_scroll') && ($_GET['mode'] ?? '') != 'minimal') {
+ $tpl = Renderer::getMarkupTemplate('infinite_scroll_head.tpl');
+ $o = Renderer::replaceMacros($tpl, ['$reload_uri' => DI::args()->getQueryString()]);
+ } else {
+ $o = '';
+ }
+
+ $file = $_GET['file'] ?? '';
+
+ // Rawmode is used for fetching new content at the end of the page
+ if (!(isset($_GET['mode']) && ($_GET['mode'] == 'raw'))) {
+ Nav::setSelected(DI::args()->get(0));
+ }
+
+ if (DI::mode()->isMobile()) {
+ $itemspage_network = DI::pConfig()->get(local_user(), 'system', 'itemspage_mobile_network',
+ DI::config()->get('system', 'itemspage_network_mobile'));
+ } else {
+ $itemspage_network = DI::pConfig()->get(local_user(), 'system', 'itemspage_network',
+ DI::config()->get('system', 'itemspage_network'));
+ }
+
+ $pager = new Pager(DI::l10n(), DI::args()->getQueryString(), $itemspage_network);
+
+ $term_condition = ['type' => Category::FILE, 'uid' => local_user()];
+ if ($file) {
+ $term_condition['name'] = $file;
+ }
+ $term_params = ['order' => ['uri-id' => true], 'limit' => [$pager->getStart(), $pager->getItemsPerPage()]];
+ $result = DBA::select('category-view', ['uri-id'], $term_condition, $term_params);
+
+ $total = DBA::count('category-view', $term_condition);
+
+ $posts = [];
+ while ($term = DBA::fetch($result)) {
+ $posts[] = $term['uri-id'];
+ }
+ DBA::close($result);
+
+ if (count($posts) == 0) {
+ return '';
+ }
+ $item_condition = ['uid' => local_user(), 'uri-id' => $posts];
+ $item_params = ['order' => ['uri-id' => true]];
+
+ $result = Item::selectForUser(local_user(), [], $item_condition, $item_params);
+ $items = Item::inArray($result);
+
+ $o .= conversation(DI::app(), $items, 'filed', false, false, '', local_user());
+
+ if (DI::pConfig()->get(local_user(), 'system', 'infinite_scroll')) {
+ $o .= HTML::scrollLoader();
+ } else {
+ $o .= $pager->renderFull($total);
+ }
+
+ return $o;
+ }
+}
diff --git a/src/Module/Update/Network.php b/src/Module/Update/Network.php
new file mode 100644
index 000000000..81bdf834e
--- /dev/null
+++ b/src/Module/Update/Network.php
@@ -0,0 +1,61 @@
+get($profile_uid, 'system', 'no_auto_update') || ($_GET['force'] == 1)) {
+ if (!empty($_GET['item'])) {
+ $item = Item::selectFirst(['parent'], ['id' => $_GET['item']]);
+ $parent = $item['parent'] ?? 0;
+ } else {
+ $parent = 0;
+ }
+
+ $conditionFields = [];
+ if (!empty($parent)) {
+ // Load only a single thread
+ $conditionFields['parent'] = $parent;
+ } elseif (self::$order === 'received') {
+ // Only load new toplevel posts
+ $conditionFields['unseen'] = true;
+ $conditionFields['gravity'] = GRAVITY_PARENT;
+ } else {
+ // Load all unseen items
+ $conditionFields['unseen'] = true;
+ }
+
+ $params = ['limit' => 100];
+ $table = 'network-item-view';
+
+ $items = self::getItems($table, $params, $conditionFields);
+
+ if (self::$order === 'received') {
+ $ordering = '`received`';
+ } else {
+ $ordering = '`commented`';
+ }
+
+ $o = conversation(DI::app(), $items, 'network', $profile_uid, false, $ordering, local_user());
+ }
+
+ System::htmlUpdateExit($o);
+ }
+}
diff --git a/static/routes.config.php b/static/routes.config.php
index 6f4850006..8ddd7250c 100644
--- a/static/routes.config.php
+++ b/static/routes.config.php
@@ -117,7 +117,7 @@ return [
'/debug/ap' => [Module\Debug\ActivityPubConversion::class, [R::GET, R::POST]],
'/bookmarklet' => [Module\Bookmarklet::class, [R::GET]],
- '/community[/{content}[/{accounttype}]]' => [Module\Conversation\Community::class, [R::GET]],
+ '/community[/{content}]' => [Module\Conversation\Community::class, [R::GET]],
'/compose[/{type}]' => [Module\Item\Compose::class, [R::GET, R::POST]],
@@ -164,6 +164,7 @@ return [
'/status_message/{guid}' => [Module\Diaspora\Fetch::class, [R::GET]],
'/reshare/{guid}' => [Module\Diaspora\Fetch::class, [R::GET]],
],
+ '/filed' => [Module\Search\Filed::class, [R::GET]],
'/filer[/{id:\d+}]' => [Module\Filer\SaveTag::class, [R::GET]],
'/filerm/{id:\d+}' => [Module\Filer\RemoveTag::class, [R::GET]],
'/follow_confirm' => [Module\FollowConfirm::class, [R::GET, R::POST]],
@@ -298,6 +299,13 @@ return [
'/userexport[/{action}]' => [Module\Settings\UserExport::class, [R::GET, R::POST]],
],
+ '/network' => [
+ '[/]' => [Module\Conversation\Network::class, [R::GET]],
+ '/archive/{from:\d\d\d\d-\d\d-\d\d}[/{to:\d\d\d\d-\d\d-\d\d}]' => [Module\Conversation\Network::class, [R::GET]],
+ '/forum/{contact_id:\d+}' => [Module\Conversation\Network::class, [R::GET]],
+ '/group/{group_id:\d+}' => [Module\Conversation\Network::class, [R::GET]],
+ ],
+
'/randprof' => [Module\RandomProfile::class, [R::GET]],
'/register' => [Module\Register::class, [R::GET, R::POST]],
'/remote_follow/{profile}' => [Module\RemoteFollow::class, [R::GET, R::POST]],
@@ -309,7 +317,8 @@ return [
'/toggle_mobile' => [Module\ToggleMobile::class, [R::GET]],
'/tos' => [Module\Tos::class, [R::GET]],
- '/update_community[/{content}[/{accounttype}]]' => [Module\Update\Community::class, [R::GET]],
+ '/update_community[/{content}]' => [Module\Update\Community::class, [R::GET]],
+ '/update_network' => [Module\Update\Network::class, [R::GET]],
'/update_profile' => [Module\Update\Profile::class, [R::GET]],
'/view/theme/{theme}/style.pcss' => [Module\Theme::class, [R::GET]],
diff --git a/view/templates/widget/filter.tpl b/view/templates/widget/filter.tpl
index 557b8794b..85a3298f5 100644
--- a/view/templates/widget/filter.tpl
+++ b/view/templates/widget/filter.tpl
@@ -7,7 +7,7 @@
{{$desc nofilter}}
diff --git a/src/Content/ForumManager.php b/src/Content/ForumManager.php
index 980e82522..c25753a84 100644
--- a/src/Content/ForumManager.php
+++ b/src/Content/ForumManager.php
@@ -99,13 +99,14 @@ class ForumManager
* Sidebar widget to show subcribed friendica forums. If activated
* in the settings, it appears at the notwork page sidebar
*
* @param int $uid The ID of the User
* @param int $cid The contact id which is used to mark a forum as "selected"
* @return string
* @throws \Friendica\Network\HTTPException\InternalServerErrorException
* @throws \ImagickException
*/
- public static function widget($uid, $cid = 0)
+ public static function widget(string $baseurl, int $uid, int $cid = 0)
{
$o = '';
@@ -125,7 +126,7 @@ class ForumManager
$selected = (($cid == $contact['id']) ? ' forum-selected' : '');
$entry = [
- 'url' => 'network?contactid=' . $contact['id'],
+ 'url' => $baseurl . '/' . $contact['id'],
'external_url' => Contact::magicLink($contact['url']),
'name' => $contact['name'],
'cid' => $contact['id'],
@@ -99,13 +99,14 @@ class ForumManager
* in the settings, it appears at the notwork page sidebar
*
- * @param int $uid The ID of the User
- * @param int $cid The contact id which is used to mark a forum as "selected"
+ * @param string $baseurl Base module path
+ * @param int $uid The ID of the User
+ * @param int $cid The contact id which is used to mark a forum as "selected"
* @return string
* @throws \Friendica\Network\HTTPException\InternalServerErrorException